@@ -116,7 +116,7 @@ class cmd_fetch_pack(Command):
             determine_wants = r.object_store.determine_wants_all
         else:
 
-            def determine_wants(x):
+            def determine_wants(x, **kwargs):
                 return [y for y in args if y not in r.object_store]
 
         client.fetch(path, r, determine_wants)
@@ -388,7 +388,6 @@ class cmd_daemon(Command):
             gitdir = args[0]
         else:
             gitdir = "."
-        from dulwich import porcelain
 
         porcelain.daemon(gitdir, address=options.listen_address, port=options.port)
 
@@ -420,7 +419,6 @@ class cmd_web_daemon(Command):
             gitdir = args[0]
         else:
             gitdir = "."
-        from dulwich import porcelain
 
         porcelain.web_daemon(gitdir, address=options.listen_address, port=options.port)
 
